# Smart Enums

This package is in pre-alpha. It's not ready to be used and it's only on pypi to protect the package name.

Smart Enums is a small package that aims to provide comfort enums from other languages like Rust, Haskell or Elm.
